@@ -45,6 +45,7 @@ type HTTPRunnerResults struct {
 	HTTPOptions
 	Sizes       *stats.HistogramData
 	HeaderSizes *stats.HistogramData
+	Sockets     []int
 	SocketCount int
 	// http code to abort the run on (-1 for connection or other socket error)
 	AbortOn int
@@ -62,7 +63,7 @@ func (httpstate *HTTPRunnerResults) Run(t int) (bool, string) {
 	httpstate.sizes.Record(float64(size))
 	httpstate.headerSizes.Record(float64(headerSize))
 	if httpstate.AbortOn == code {
-		httpstate.aborter.Abort()
+		httpstate.aborter.Abort(false)
 		log.Infof("Aborted run because of code %d - data %s", code, DebugSummary(body, 1024))
 	}
 	if code == http.StatusOK {
@@ -83,7 +84,8 @@ type HTTPRunnerOptions struct {
 }
 
 // RunHTTPTest runs an http test and returns the aggregated stats.
-// nolint: funlen, gocognit, gocyclo
+//
+//nolint:funlen, gocognit, gocyclo
 func RunHTTPTest(o *HTTPRunnerOptions) (*HTTPRunnerResults, error) {
 	o.RunType = "HTTP"
 	warmupMode := "parallel"
@@ -190,14 +192,15 @@ func RunHTTPTest(o *HTTPRunnerOptions) (*HTTPRunnerResults, error) {
 	numThreads = total.RunnerResults.NumThreads
 	// But we also must cleanup all the created clients.
 	keys := []int{}
+	fmt.Fprintf(out, "# Socket and IP used for each connection:\n")
 	for i := 0; i < numThreads; i++ {
 		// Get the report on the IP address each thread use to send traffic
-		ip := httpstate[i].client.GetIPAddress()
-		currentSocketUsed := httpstate[i].client.Close()
-		log.Infof("[%d] %3d socket used, resolved to %s\n", i, currentSocketUsed, ip)
-		total.IPCountMap[ip]++
+		occurrence, currentSocketUsed := httpstate[i].client.GetIPAddress()
+		httpstate[i].client.Close()
+		fmt.Fprintf(out, "[%d] %3d socket used, resolved to %s\n", i, currentSocketUsed, occurrence.PrintAndAggregate(total.IPCountMap))
 
 		total.SocketCount += currentSocketUsed
+		total.Sockets = append(total.Sockets, currentSocketUsed)
 		// Q: is there some copying each time stats[i] is used?
 		for k := range httpstate[i].RetCodes {
 			if _, exists := total.RetCodes[k]; !exists {
